@@ -442,8 +442,13 @@ class water:
         classifier = 'naivebayes'
         clustering_method = 'agglomerative'
         
-        def __init__(self,bands):
-            self.bands = bands   
+        def __init__(self,input_bands):
+            self.input_bands = input_bands   
+            bands = dict()
+            for i,j in bands3.items():
+                quantize = j.squeeze()/10000
+                bands.update({i:quantize})
+            self.bands=bands
             
         def __str__(self):
             lst = list()
